#!/bin/sh

# Icecast install on Fedora 36

# Set an Icecast source password and admin password
SOURCE_PASSWORD='set_your_password_here'
ADMIN_PASSWORD='set_your_password_here'

# Vultr broken NS fix

echo "DNS=1.1.1.1" >> /etc/systemd/resolved.conf
systemctl restart systemd-resolved.service

# Grab the external IP of the server
IPADR=`curl checkip.amazonaws.com`

# Disable firewalld (Cloud provider firewall will suffice)
systemctl stop firewalld

# Install Icecast
dnf install -y icecast

# Generate self-signed SSL certificate
openssl req -x509 -nodes -days 365 -subj '/CN=icecastserver/O=icecastserver/C=SG' -newkey rsa:4096 -keyout /usr/share/icecast/ssl.crt -out /usr/share/icecast/ssl.crt
chmod 644 /usr/share/icecast/ssl.crt

# Setup Icecast configuration
cat <<EOF > /etc/icecast.xml
<icecast>
    <limits>
        <clients>100</clients>
        <sources>10</sources>
        <threadpool>5</threadpool>
        <queue-size>2046000</queue-size>
        <client-timeout>30</client-timeout>
        <header-timeout>15</header-timeout>
        <source-timeout>10</source-timeout>
        <burst-on-connect>1</burst-on-connect>
        <burst-size>1024000</burst-size>
    </limits>

    <authentication>
        <source-password>$SOURCE_PASSWORD</source-password>
        <admin-user>admin</admin-user>
        <admin-password>$ADMIN_PASSWORD</admin-password>
    </authentication>

    <listen-socket>
        <port>443</port>
        <bind-address>$IPADR</bind-address>
                <ssl>1</ssl>
    </listen-socket>

    <paths>
        <ssl-certificate>/usr/share/icecast/ssl.crt</ssl-certificate>
        <logdir>/var/log/icecast</logdir>
        <webroot>/usr/share/icecast/web</webroot>
        <adminroot>/usr/share/icecast/admin</adminroot>
        <pidfile>/var/run/icecast/icecast.pid</pidfile>
        <alias source="/" dest="/status.xsl"/>
    </paths>

    <logging>
        <accesslog>access.log</accesslog>
        <errorlog>error.log</errorlog>
        <loglevel>3</loglevel>
        <logsize>10000</logsize>
    </logging>

    <security>
        <chroot>0</chroot>
        <changeowner>
            <user>icecast</user>
            <group>icecast</group>
        </changeowner>
    </security>
</icecast>
EOF

# Set icecast to permissive for SELinux
semanage permissive -a icecast_t

# Start Icecast
systemctl start icecast
